# © 2022 Le Filament (<http://www.le-filament.com>)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import fields, models


class ResPartner(models.Model):
    _name = "res.partner"
    _inherit = ["portal.mixin", "res.partner"]

    # ------------------------------------------------------
    # Fields declaration
    # ------------------------------------------------------
    release_ids = fields.One2many(
        comodel_name="res.partner.release", inverse_name="partner_id", string="Releases"
    )
    module_ids = fields.One2many(
        comodel_name="res.partner.module", inverse_name="partner_id", string="Modules"
    )
    release_share_link = fields.Char(
        string="Lien de partage client",
        compute="_compute_release_share_link",
    )

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------
    def _compute_release_share_link(self):
        for partner in self:
            if partner.access_token:
                partner.release_share_link = (
                    partner.get_base_url()
                    + "/releases?partner="
                    + str(partner.id)
                    + "&access_token="
                    + partner.access_token
                )
            else:
                partner.release_share_link = ""

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------
    def set_release_url(self):
        for partner in self:
            if partner.is_company:
                partner._portal_ensure_token()

    # ------------------------------------------------------
    # Common function
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Portal methods
    # ------------------------------------------------------
